# Install 
```bash
> python3 -m pip install shot-on-iphone
> python3
```
```python
>>> from shot_on_iphone import Iphone
>>> Iphone('video.mp4').save('meme.mp4')
"""
Use Threads
"""
>>> Iphone('video.mp4').save('meme.mp4', threads=5)
```
# Donasi
<ul><li><a href="https://saweria.co/kryptonbyte">Saweria</a><li><a href="https://wa.me/6283172366463">Whatsapp</a></li></ul>